pub enum SkippableChecksum<D: DigestString + Clone> {
Skip,
Checksum {
digest: Checksum<D>,
},
}Expand description
A Checksum that may be skipped.
Strings representing checksums are used to verify the integrity of files.
If the "SKIP" keyword is found, the integrity check is skipped.
Variants
Skip
Sourcefile checksum validation may be skipped, which is expressed with this variant.
Checksum
The related source file should be validated via the provided checksum.
Implementations
Sourceimpl<D: DigestString + Clone> SkippableChecksum<D>
impl<D: DigestString + Clone> SkippableChecksum<D>
Sourcepub fn is_skipped(&self) -> bool
pub fn is_skipped(&self) -> bool
Determines whether the SkippableChecksum is skipped.
Checksums are considered skipped if they are of the variant SkippableChecksum::Skip.