Struct Sha384
pub struct Sha384 {
pub(crate) core: CtOutWrapper<Sha512VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B1>, B0>, B0>, B0>, B0>>,
pub(crate) buffer: BlockBuffer<<CtOutWrapper<Sha512VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B1>, B0>, B0>, B0>, B0>> as BlockSizeUser>::BlockSize, <CtOutWrapper<Sha512VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B1>, B0>, B0>, B0>, B0>> as BufferKindUser>::BufferKind>,
}Expand description
SHA-384 hasher.
Fields
core: CtOutWrapper<Sha512VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B1>, B0>, B0>, B0>, B0>>buffer: BlockBuffer<<CtOutWrapper<Sha512VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B1>, B0>, B0>, B0>, B0>> as BlockSizeUser>::BlockSize, <CtOutWrapper<Sha512VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B1>, B0>, B0>, B0>, B0>> as BufferKindUser>::BufferKind>Trait Implementations
impl CoreProxy for Sha384
impl CoreProxy for Sha384
type Core = CtOutWrapper<Sha512VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B1>, B0>, B0>, B0>, B0>>
type Core = CtOutWrapper<Sha512VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B1>, B0>, B0>, B0>, B0>>
Core block-level type.
Sourceimpl DigestString for Sha384
impl DigestString for Sha384
Sourceconst ENCODING: DigestEncoding = DigestEncoding::Hex
const ENCODING: DigestEncoding = DigestEncoding::Hex
The format used for string representation of the digest.
impl FixedOutput for Sha384
impl FixedOutput for Sha384
fn finalize_into(
self,
out: &mut Array<u8, <Sha384 as OutputSizeUser>::OutputSize>,
)
fn finalize_into( self, out: &mut Array<u8, <Sha384 as OutputSizeUser>::OutputSize>, )
Consume value and write result into provided array.
fn finalize_fixed(self) -> Array<u8, Self::OutputSize>
fn finalize_fixed(self) -> Array<u8, Self::OutputSize>
Retrieve result and consume the hasher instance.
impl FixedOutputReset for Sha384
impl FixedOutputReset for Sha384
fn finalize_into_reset(
&mut self,
out: &mut Array<u8, <Sha384 as OutputSizeUser>::OutputSize>,
)
fn finalize_into_reset( &mut self, out: &mut Array<u8, <Sha384 as OutputSizeUser>::OutputSize>, )
Write result into provided array and reset the hasher state.
fn finalize_fixed_reset(&mut self) -> Array<u8, Self::OutputSize>
fn finalize_fixed_reset(&mut self) -> Array<u8, Self::OutputSize>
Retrieve result and reset the hasher state.
impl HashMarker for Sha384
impl SerializableState for Sha384
impl SerializableState for Sha384
type SerializedStateSize = <<CtOutWrapper<Sha512VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B1>, B0>, B0>, B0>, B0>> as SerializableState>::SerializedStateSize as Add<<<CtOutWrapper<Sha512VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B1>, B0>, B0>, B0>, B0>> as BlockSizeUser>::BlockSize as Add<<<CtOutWrapper<Sha512VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B1>, B0>, B0>, B0>, B0>> as BufferKindUser>::BufferKind as Sealed>::Overhead>>::Output>>::Output
type SerializedStateSize = <<CtOutWrapper<Sha512VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B1>, B0>, B0>, B0>, B0>> as SerializableState>::SerializedStateSize as Add<<<CtOutWrapper<Sha512VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B1>, B0>, B0>, B0>, B0>> as BlockSizeUser>::BlockSize as Add<<<CtOutWrapper<Sha512VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B1>, B0>, B0>, B0>, B0>> as BufferKindUser>::BufferKind as Sealed>::Overhead>>::Output>>::Output
Size of serialized internal state.