pub enum MakepkgOption {
BuildEnvironment(BuildEnvironmentOption),
Package(PackageOption),
}Expand description
Wraps the PackageOption and BuildEnvironmentOption enums.
This is necessary for metadata files such as SRCINFO or PKGBUILD package scripts that don’t differentiate between the different types and scopes of options.
Variants
BuildEnvironment(BuildEnvironmentOption)
Package(PackageOption)