Enum Source 

pub enum Source {
    File {
        filename: Option<PathBuf>,
        location: PathBuf,
    },
    SourceUrl {
        filename: Option<PathBuf>,
        source_url: SourceUrl,
    },
}
Represents the location that a source file should be retrieved from

It can be either a local file (next to the PKGBUILD) or a URL.

Variants



File

A local file source.

The location must be a pure file name, without any path components (/). Hence, the file must be located directly next to the PKGBUILD.

Fields

filename: Option<PathBuf>

The optional destination file name.

location: PathBuf

The source file name.



SourceUrl

A URL source.

Fields

filename: Option<PathBuf>

The optional destination file name.

source_url: SourceUrl

The source URL.

Implementations

Source

impl Source

pub fn filename(&self) -> Option<&PathBuf>

Returns the filename of the source if it is set.