pub enum VersionComparison {
LessOrEqual,
GreaterOrEqual,
Equal,
Less,
Greater,
}Expand description
Specifies the comparison function for a VersionRequirement.
The package version can be required to be:
- less than (
<) - less than or equal to (
<=) - equal to (
=) - greater than or equal to (
>=) - greater than (
>)
the specified version.
See alpm-comparison for details on the format.
Note
The variants of this enum are sorted in a way, that prefers the two-letter comparators over
the one-letter ones.
This is because when splitting a string on the string representation of VersionComparison
variant and relying on the ordering of [strum::EnumIter], the two-letter comparators must be
checked before checking the one-letter ones to yield robust results.
Variants
LessOrEqual
Less than or equal to
GreaterOrEqual
Greater than or equal to
Equal
Equal to
Less
Less than
Greater
Greater than
Implementations
Sourceimpl VersionComparison
impl VersionComparison
Sourcefn is_compatible_with(self, ord: Ordering) -> bool
fn is_compatible_with(self, ord: Ordering) -> bool
Returns true if the result of a comparison between the actual and required package
versions satisfies the comparison function.