pub enum BuildEnvironmentOption {
BuildFlags(bool),
Ccache(bool),
Check(bool),
Color(bool),
Distcc(bool),
Sign(bool),
MakeFlags(bool),
}Expand description
An option string used in a build environment
The option string is identified by its name and whether it is on (not prefixed with “!”) or off (prefixed with “!”).
See the makepkg.conf manpage for more information.
Examples
use alpm_types::BuildEnvironmentOption;
let option = BuildEnvironmentOption::new("distcc")?;
assert_eq!(option.on(), true);
assert_eq!(option.name(), "distcc");
let not_option = BuildEnvironmentOption::new("!ccache")?;
assert_eq!(not_option.on(), false);
assert_eq!(not_option.name(), "ccache");Variants
BuildFlags(bool)
Use or unset the values of build flags (e.g. CPPFLAGS, CFLAGS, CXXFLAGS, LDFLAGS)
specified in user-specific configs (e.g. makepkg.conf).
Ccache(bool)
Use ccache to cache compilation
Check(bool)
Run the check() function if present in the PKGBUILD
Color(bool)
Colorize output messages
Distcc(bool)
Use the Distributed C/C++/ObjC compiler
Sign(bool)
Generate PGP signature file
MakeFlags(bool)
Use or unset the value of the MAKEFLAGS environment variable specified in
user-specific configs (e.g. makepkg.conf).
Implementations
Sourceimpl BuildEnvironmentOption
impl BuildEnvironmentOption