pub enum PackageOption {
AutoDeps(bool),
Debug(bool),
Docs(bool),
EmptyDirs(bool),
Libtool(bool),
Lto(bool),
PEStrip(bool),
Purge(bool),
StaticLibs(bool),
Strip(bool),
Zipman(bool),
}Expand description
An option string used in packaging
The option string is identified by its name and whether it is on (not prefixed with “!”) or off (prefixed with “!”).
See the makepkg.conf manpage for more information.
Examples
use alpm_types::PackageOption;
let option = PackageOption::new("debug")?;
assert_eq!(option.on(), true);
assert_eq!(option.name(), "debug");
let not_option = PackageOption::new("!lto")?;
assert_eq!(not_option.on(), false);
assert_eq!(not_option.name(), "lto");Variants
AutoDeps(bool)
Automatically add dependencies and provisions (see alpm-sonamev2).
Debug(bool)
Add debugging flags as specified in DEBUG_* variables
Docs(bool)
Save doc directories specified by DOC_DIRS
EmptyDirs(bool)
Leave empty directories in packages
Libtool(bool)
Leave libtool (.la) files in packages
Lto(bool)
Add compile flags for building with link time optimization
PEStrip(bool)
Strip debug symbols from Portable Executable (PE) format files
Purge(bool)
Remove files specified by PURGE_TARGETS
StaticLibs(bool)
Leave static library (.a) files in packages
Strip(bool)
Strip symbols from binaries/libraries
Zipman(bool)
Compress manual (man and info) pages in MAN_DIRS with gzip
Implementations
Sourceimpl PackageOption
impl PackageOption
Sourcepub fn new(option: &str) -> Result<Self, Error>
pub fn new(option: &str) -> Result<Self, Error>
Creates a new PackageOption from a string slice.
Errors
An error is returned if the string slice does not match a valid package option.
Sourcepub fn name(&self) -> &str
pub fn name(&self) -> &str
Returns the name of the PackageOption as string slice.
Sourcepub fn on(&self) -> bool
pub fn on(&self) -> bool
Returns whether the PackageOption is on or off.