pub struct SharedObjectName(pub(crate) String);Expand description
A shared object name.
This type wraps a Name and is used to represent the name of a shared object file
that ends with the .so suffix.
Tuple Fields
0: StringImplementations