pub struct PackageRelation {
pub name: Name,
pub version_requirement: Option<VersionRequirement>,
}Expand description
A package relation
Describes a relation to a component.
Package relations may either consist of only a Name or of a Name and a
VersionRequirement.
Note
A PackageRelation covers all alpm-package-relations except optional
dependencies, as those behave differently.
Fields
name: NameThe name of the package
version_requirement: Option<VersionRequirement>The version requirement for the package
Implementations
Sourceimpl PackageRelation
impl PackageRelation
Sourcepub fn new(name: Name, version_requirement: Option<VersionRequirement>) -> Self
pub fn new(name: Name, version_requirement: Option<VersionRequirement>) -> Self
Creates a new PackageRelation
Examples
use alpm_types::{PackageRelation, VersionComparison, VersionRequirement};
PackageRelation::new(
"example".parse()?,
Some(VersionRequirement {
comparison: VersionComparison::Less,
version: "1.0.0".parse()?,
}),
);
PackageRelation::new("example".parse()?, None);Trait Implementations
Sourceimpl AlpmParser for PackageRelation
impl AlpmParser for PackageRelation
Sourcefn parser(input: &mut &str) -> ModalResult<Self>
fn parser(input: &mut &str) -> ModalResult<Self>
Recognizes a PackageRelation in a string slice.
Examples
See Self::from_str for code examples.
Errors
Returns an error if input does not begin with a valid alpm-package-relation.
Sourceimpl Clone for PackageRelation
impl Clone for PackageRelation
Sourcefn clone(&self) -> PackageRelation
fn clone(&self) -> PackageRelation
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PackageRelation
impl Debug for PackageRelation
Sourceimpl<'de> Deserialize<'de> for PackageRelation
impl<'de> Deserialize<'de> for PackageRelation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Display for PackageRelation
impl Display for PackageRelation
Sourceimpl FromStr for PackageRelation
impl FromStr for PackageRelation
Sourcefn from_str(s: &str) -> Result<Self, Self::Err>
fn from_str(s: &str) -> Result<Self, Self::Err>
Parses a PackageRelation from a string slice.
Delegates to PackageRelation::parser.
Errors
Returns an error if PackageRelation::parser fails.
Examples
use std::str::FromStr;
use alpm_types::{PackageRelation, VersionComparison, VersionRequirement};
assert_eq!(
PackageRelation::from_str("example<1.0.0")?,
PackageRelation::new(
"example".parse()?,
Some(VersionRequirement {
comparison: VersionComparison::Less,
version: "1.0.0".parse()?
})
),
);
assert_eq!(
PackageRelation::from_str("example<=1.0.0")?,
PackageRelation::new(
"example".parse()?,
Some(VersionRequirement {
comparison: VersionComparison::LessOrEqual,
version: "1.0.0".parse()?
})
),
);
assert_eq!(
PackageRelation::from_str("example=1.0.0")?,
PackageRelation::new(
"example".parse()?,
Some(VersionRequirement {
comparison: VersionComparison::Equal,
version: "1.0.0".parse()?
})
),
);
assert_eq!(
PackageRelation::from_str("example>1.0.0")?,
PackageRelation::new(
"example".parse()?,
Some(VersionRequirement {
comparison: VersionComparison::Greater,
version: "1.0.0".parse()?
})
),
);
assert_eq!(
PackageRelation::from_str("example>=1.0.0")?,
PackageRelation::new(
"example".parse()?,
Some(VersionRequirement {
comparison: VersionComparison::GreaterOrEqual,
version: "1.0.0".parse()?
})
),
);
assert_eq!(
PackageRelation::from_str("example")?,
PackageRelation::new("example".parse()?, None),
);
assert!(PackageRelation::from_str("example<").is_err());Sourceimpl PartialEq<PackageRelation> for RelationOrSoname
impl PartialEq<PackageRelation> for RelationOrSoname
Sourcefn eq(&self, other: &PackageRelation) -> bool
fn eq(&self, other: &PackageRelation) -> bool
self and other values to be equal, and is used by ==.Sourceimpl PartialEq for PackageRelation
impl PartialEq for PackageRelation
Sourcefn eq(&self, other: &PackageRelation) -> bool
fn eq(&self, other: &PackageRelation) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PackageRelation
impl Serialize for PackageRelation
impl Eq for PackageRelation
impl StructuralPartialEq for PackageRelation