pub struct Name(String);Expand description
A package name
Package names may contain the characters [a-zA-Z0-9\-._@+], but must not
start with [-.] (see alpm-package-name).
Examples
use std::str::FromStr;
use alpm_types::{Error, Name};
// create Name from &str
assert_eq!(
Name::from_str("test-123@.foo_+"),
Ok(Name::new("test-123@.foo_+")?)
);
assert!(Name::from_str(".test").is_err());
// format as String
assert_eq!("foo", format!("{}", Name::new("foo")?));Tuple Fields
0: StringImplementations
Sourceimpl Name
impl Name
Sourceconst SPECIAL_FIRST_CHARS: [char; 3]
const SPECIAL_FIRST_CHARS: [char; 3]
The subset of special characters that are allowed as first character of a Name.
Sourceconst NEVER_FIRST_CHAR: [char; 5]
const NEVER_FIRST_CHAR: [char; 5]
The set of characters allowed anywhere in a Name, except as first character.
Sourceimpl Name
impl Name
Sourcepub(crate) fn parse_name_followed_by_version<'a>(
delimiter_count: usize,
) -> impl Parser<&'a str, Self, ErrMode<ContextError>>
pub(crate) fn parse_name_followed_by_version<'a>( delimiter_count: usize, ) -> impl Parser<&'a str, Self, ErrMode<ContextError>>
Recognizes a Name as part of an InstalledPackage.
Warning
This parser is designed specifically for the internal
InstalledPackage parser.
InstalledPackage is a very special use-case, as it uses
dashes (-) as delimiter. However, dashes are also valid characters in a Name.
As such, the Name parser must be aware of how many dashes are expected to be inside the
input string to parse.
This is a necessary, albeit cursed hack due to
InstalledPackage’s dash-based delimiter design.
In contrast to Name::parser, this function expects the final character to be a -,
which it does not consume.
Errors
Returns an error if input does not begin with a valid alpm-package-name.