pub struct PackageRelease {
pub major: usize,
pub minor: Option<usize>,
}Expand description
The release version of a package.
A PackageRelease wraps a usize for its major version and an optional usize for its
minor version.
PackageRelease is used to indicate the build version of a package.
It is mostly useful in conjunction with a PackageVersion (see Version).
Refer to alpm-pkgrel for more details on the format.
Examples
use std::str::FromStr;
use alpm_types::PackageRelease;
assert!(PackageRelease::from_str("1").is_ok());
assert!(PackageRelease::from_str("1.1").is_ok());
assert!(PackageRelease::from_str("0").is_ok());
assert!(PackageRelease::from_str("a").is_err());
assert!(PackageRelease::from_str("1.a").is_err());Fields
major: usizeThe major version of this package release.
minor: Option<usize>The optional minor version of this package release.
Implementations