pub struct SonameV2 {
pub prefix: SharedLibraryPrefix,
pub soname: Soname,
}Expand description
Representation of soname data of a shared object based on the alpm-sonamev2 specification.
Soname data may be used as alpm-package-relation of type provision or run-time dependency
in PackageInfoV1 and PackageInfoV2. The data consists of the arbitrarily
defined prefix, which denotes the use name of a specific library directory, and the soname,
which refers to the value of either the SONAME or a NEEDED field in the dynamic section of
an ELF file.
Examples
This example assumpes that lib is used as the prefix for the library directory /usr/lib
and the following files are contained in it:
/usr/lib/libexample.so -> libexample.so.1
/usr/lib/libexample.so.1 -> libexample.so.1.0.0
/usr/lib/libexample.so.1.0.0The above file /usr/lib/libexample.so.1.0.0 represents an ELF file, that exposes
libexample.so.1 as value of the SONAME field in its dynamic section. This data can be
represented as follows, using SonameV2:
use alpm_types::{Soname, SonameV2};
let soname_data = SonameV2 {
prefix: "lib".parse()?,
soname: Soname {
name: "libexample.so".parse()?,
version: Some("1".parse()?),
},
};
assert_eq!(soname_data.to_string(), "lib:libexample.so.1");Fields
prefix: SharedLibraryPrefixThe directory prefix of the shared object file.
soname: SonameThe soname of a shared object file.
Implementations