pub struct SourceUrl {
pub url: Url,
pub vcs_info: Option<VcsInfo>,
}Expand description
A URL for package sources.
Wraps the Url type and provides optional information on VCS systems.
Can be created from custom URL strings, that in part resemble the default URL syntax, e.g.:
git+https://example.org/example-project.git#tag=v1.0.0?signedThe above example provides an overview of the custom URL syntax:
- The optional VCS specifier
gitis prepended, directly followed by a “+” sign as delimiter, - specific URL
fragmenttypes such astagare used to encode information about the particular VCS objects to address, - the URL
querycomponentsignedis used to indicate that OpenPGP signature verification is required for a VCS type.
Note
The URL format used by SourceUrl deviates from the default URL syntax by allowing to
change the order of the query and fragment component!
Refer to the alpm-package-source documentation for a more detailed overview of the custom URL syntax.
Examples
use std::str::FromStr;
use alpm_types::SourceUrl;
// Create Url from &str
let url =
SourceUrl::from_str("git+https://your-vcs.org/example-project.git?signed#tag=v1.0.0")?;
assert_eq!(
&url.to_string(),
"git+https://your-vcs.org/example-project.git?signed#tag=v1.0.0"
);Fields
url: UrlThe URL from where the sources are retrieved.
vcs_info: Option<VcsInfo>Optional data on VCS systems using the URL for the retrieval of sources.