pub struct Epoch(pub usize);Expand description
An epoch of a package
Epoch is used to indicate the downgrade of a package and is prepended to a version, delimited by
a ":" (e.g. 1: is added to 0.10.0-1 to form 1:0.10.0-1 which then orders newer than
1.0.0-1).
See alpm-epoch for details on the format.
An Epoch wraps a usize.
Examples
use std::str::FromStr;
use alpm_types::Epoch;
assert!(Epoch::from_str("0").is_ok());
assert!(Epoch::from_str("1").is_ok());Tuple Fields
0: usizeImplementations