pub enum Source {
File {
filename: Option<PathBuf>,
location: PathBuf,
},
SourceUrl {
filename: Option<PathBuf>,
source_url: SourceUrl,
},
}Expand description
Represents the location that a source file should be retrieved from
It can be either a local file (next to the PKGBUILD) or a URL.
Variants
File
A local file source.
The location must be a pure file name, without any path components (/).
Hence, the file must be located directly next to the PKGBUILD.
Fields
SourceUrl
A URL source.
Implementations